#ifndef MAILHEAD_H
#define MAILHEAD_H

#define MAXHLINE	200

class MAILADR{
public:
	char adr[MAXHLINE+1];
	char name[MAXHLINE+1];
	/*~PROTOBEG~ MAILADR */
public:
	MAILADR (void);
	/*~PROTOEND~ MAILADR */
};

class MAILHEADER {
public:
	int nbreceived;
	MAILADR from;
	MAILADR to;
	char reply[MAXHLINE+1];
	char subject[MAXHLINE+1];
	char msgid[MAXHLINE+1];
	char replyid[MAXHLINE+1];
	char date[MAXHLINE+1];
	char priority[MAXHLINE+1];
	/*~PROTOBEG~ MAILHEADER */
public:
	MAILHEADER (void);
	/*~PROTOEND~ MAILHEADER */
};

#include "mailhead.p"

#endif

